@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.038001";
+$VERSION = "5.038002";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.38.1) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.38.2) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.38.1
-    or die sprintf "%s: Perl lib version (5.38.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.38.2
+    or die sprintf "%s: Perl lib version (5.38.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -96,7 +96,7 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /usr/lib',
+    libpth => '/usr/local/lib /usr/lib /usr/lib/db5.3',
     osname => 'linux',
     osvers => '5.12.15-arch1-1',
     path_sep => ':',
@@ -107,5 +107,5 @@ tie %Config, 'Config', {
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.38.1',
+    version => '5.38.2',
 };
